@@ -1,17 +1,8 @@
 
 #include <stdio.h>
 
-#include <caml/mlvalues.h>
-#include <caml/alloc.h>
-#include <caml/memory.h>
-#include <caml/callback.h>
-#include <caml/fail.h>
-#include <caml/bigarray.h>
-#include <caml/custom.h>
-
 #include <SDL.h>
 
-#include "config.h"
 #include "common.h"
 #include "sdlvideo_stub.h"
 #include "sdlrwops_stub.h"
@@ -115,15 +106,6 @@ void sdlvideo_raise_exception (char *msg)
 /*
  * some static conversion functions
  */
-#ifndef HAVE_INLINE
-static inline void SDLColor_of_value(SDL_Color *c, value v)
-{
-  c->r = Int_val(Field(v, 0));
-  c->g = Int_val(Field(v, 1));
-  c->b = Int_val(Field(v, 2));
-}
-#endif
-
 static value value_of_Rect(SDL_Rect r)
 {
   value v = alloc_small(4, 0);
@@ -199,9 +181,16 @@ static value val_video_flag(Uint32 flags)
   value l = nil();
   lookup_info *table = ml_table_video_flag;
   int i;
-  for (i = table[0].data; i > 0; i--)
-    if (flags & table[i].data) 
-      l = cons(table[i].key, l);
+  for (i = table[0].data; i > 0; i--) {
+    lookup_info f = table[i];
+    if (f.data != 0 && ((flags & f.data) == f.data))
+      l = cons(f.key, l);
+  }
+
+  /* special case for SDL_SWSURFACE because its value is 0 */
+  if ((flags & SDL_HWSURFACE) == 0)
+    l = cons(MLTAG_SWSURFACE, l);
+
   return l;
 }
 
@@ -252,24 +241,12 @@ CAMLprim value ml_SDL_SetPalette(value surf, value flags,
   int c_flags;
   int n = Wosize_val(c_arr);
   int i, status;
-#ifdef __GNUC__
-  SDL_Color color[n];
-#else
-  SDL_Color *color = calloc(sizeof(SDL_Color), n);
-#endif
+  LOCALARRAY(SDL_Color, color, n);
 
-  if(! p) {
-#ifndef __GNUC__
-    free(color);
-#endif
+  if(! p)
     invalid_argument("surface not palettized");
-  }
-  if(firstcolor + n > p->ncolors || firstcolor < 0) {
-#ifndef __GNUC__
-    free(color);
-#endif
+  if(firstcolor + n > p->ncolors || firstcolor < 0)
     invalid_argument("out of bounds palette access");
-  }
 
   for(i=0; i< n; i++)
     SDLColor_of_value(&color[i], Field(c_arr, i));
@@ -279,9 +256,6 @@ CAMLprim value ml_SDL_SetPalette(value surf, value flags,
     c_flags = Int_val(Unopt(flags)) +1 ;
 
   status = SDL_SetPalette(s, c_flags, color, ofirstcolor, n);
-#ifndef __GNUC__
-  free(color);
-#endif
   return Val_bool(status);
 }
   
@@ -420,19 +394,12 @@ CAMLprim value ml_SDL_UpdateRects(value rectl, value screen)
 {
   int len = list_length(rectl);
   register int i;
-#ifdef __GNUC__
-  SDL_Rect r[len];
-#else
-  SDL_Rect *r = calloc(sizeof(SDL_Rect), len);
-#endif
+  LOCALARRAY(SDL_Rect, r, len);
   for(i=0; i<len; i++){
     SDLRect_of_value(&r[i], hd(rectl));
     rectl = tl(rectl);
   }
   SDL_UpdateRects(SDL_SURFACE(screen), len, r);
-#ifndef __GNUC__
-  free(r);
-#endif
   return Val_unit;
 }
 
@@ -676,7 +643,7 @@ CAMLprim value ml_SDL_GetClipRect(value s)
 
 
 /* 
- * surface blittinf and conversion
+ * surface blitting and conversion
  */
 
 CAMLprim value ml_SDL_BlitSurface(value src_s, value osrc_r, 
